@@ -86,14 +86,20 @@
         <translation>Sinun on annettava teemalle nimi.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="0"/>
-        <source>Folder </source>
-        <translation>Kansio </translation>
+        <source>Overwrite existing theme?</source>
+        <translation>Korvataanko olemassa oleva teema?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="0"/>
-        <source> already exists!</source>
-        <translation> on jo olemassa!</translation>
+        <source>Theme with this name already exists, do you want to overwrite it?</source>
+        <translation>Tällä nimellä on jo teema, haluatko korvata sen?</translation>
+    </message>
+    <message>
+        <source>Theme </source>
+        <translation>Teema </translation>
+    </message>
+    <message>
+        <source> already exists and cannot be overwritten!</source>
+        <translation> on jo olemassa, eikä ole ylikirjoitettavissa!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
@@ -208,7 +214,7 @@
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Ok, thanks.</source>
-        <translation>Sulje</translation>
+        <translation>Ok, kiitti.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
