@@ -86,14 +86,20 @@
         <translation>Vous devez donner un nom au thème.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="0"/>
-        <source>Folder </source>
-        <translation>Dossier </translation>
+        <source>Theme </source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="0"/>
-        <source> already exists!</source>
-        <translation> existe dèja!</translation>
+        <source> already exists and cannot be overwritten!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overwrite existing theme?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme with this name already exists, do you want to overwrite it?</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
